using System;
using System.Collections.Generic;
using System.Text;

using Perception.FormulaDatabase.Functions;
using Perception.FormulaDatabase.FunctionSupport;
using RecordingInterface;

namespace FormulaDBFunctions
{
    public class MyFunctionInfo : IFunctionInfo
    {
        #region IFunctionInfo Members

        public string Category
        {
            get
            {
                return "CSI Functions";
            }
        }

        public IFunction CreateFunction()
        {
            // for testing purposes as long as the function
            // is not implemented: return null;
            return new CreateWaveformFromAverage();
        }

        public string Description
        {
            get
            {
                return "Creates a DC waveform with value of average of the waveform to process (InWave).";
            }
        }

        public string Example
        {
            get
            {
                return "@CSI_MeanWave(Active.Group1.Recorder1.Ch_A2)";
            }
        }

        public int MinimumParameterCount
        {
            get
            {
                return 1;
            }
        }

        public string Name
        {
            get
            {
                return "CSI_MeanWave";
            }
        }

        public string[] ParameterDescriptions
        {
            get
            {
                string[] ParamDescriptions = { "The waveform to process" };
                return ParamDescriptions;
            }
        }

        public string[] ParameterNames
        {
            get
            {
                string[] ParamNames = { "InWave" };
                return ParamNames;
            }
        }

        public DataSrcManager.PoolEntryType[] ParameterTypes
        {
            get
            {
                DataSrcManager.PoolEntryType[] PETypes = { DataSrcManager.PoolEntryType.PoolEntryType_Waveform };
                return PETypes;
            }
        }

        #endregion
    }

    public class CreateWaveformFromAverage : FunctionBase
    {
        public override DataSourceDataType DataType
        {
            get { return DataSourceDataType.DataSourceDataType_AnalogWaveform; }
        }

        public override void Reset()
        {
            //
        }
    }
}
